==> sv_v0.11.tgz: supervisor/client.tcl <==
#!/bin/sh
# the next line restarts using tclsh\
exec tclsh "$0" "$@"

#  Testing connection between Tcl applications: client side.
# Usage: ./client.tcl [port [host]]

# Default port number and host:
set port 1235
set host 127.0.0.1

# flag of command replied (ok at start)
set cmdok 1

proc getreply {} {
	global chanID cmdok stopvar
	if { [gets $chanID a]>=0 } {
		puts "<-$a"
		set cmdok 1
	} else {
		# server died?
		if { [eof $chanID] } {
			close $chanID
			puts "End of file on server channel."
			set stopvar 2
			set cmdok 0
		} else {
			puts "neither eof nor empty string..."
		}
	}
}

proc commands {} {
	global stopvar chanID cmdok
	# not allow the reading stdin to block the process:
	fconfigure stdin -blocking false
	set prompt 0
	while { $cmdok } {
		if { ! $prompt } {
			puts -nonewline "->"
			flush stdout
			set prompt 1
		}
		if { [gets stdin a]<0 } { update; continue }
		set prompt 0
		if {[string length $a]==0} {
			set stopvar 1; 
			puts "Stop. Close channel $chanID"
			close $chanID 
			break
		}
		set cmdok false
		puts $chanID "$a"
		flush $chanID
		# wait with next commands until previous command processed or 
		# cmdok is reset to false:
		vwait cmdok
	}
	puts "End of commands"
}

proc bkgr {} {
	after 1000 bkgr
	puts -nonewline \a
	flush stdout
}

# change port and host if supplied:
if {$argc>0} {set port [lindex $argv 0]}
if {$argc>1} {set host [lindex $argv 1]}

puts "Connecting to $host, port $port..."
if {[catch {set chanID [ socket $host $port ]}]} {
	puts "Server not available. Exit"
	exit
} else {
	puts " Connected to $host at port=$port in channel ID $chanID. Input commands:"
	fileevent $chanID readable getreply
}
set stopvar 0
bkgr
# we have to start commands() on background to enter event loop by the command
# after its start:
after idle commands
vwait stopvar
exit

==> sv_v0.13.tgz: supervisor/client.tcl <==
#!/bin/sh
# the next line restarts using tclsh\
exec tclsh "$0" "$@"

#  Testing connection between Tcl applications: client side.
# Usage: ./client.tcl [port [host]]

# Default port number and host:
set port 1235
set host 127.0.0.1

# flag of command replied (ok at start)
set cmdok 1

proc getreply {} {
	global chanID cmdok stopvar
	if { [gets $chanID a]>=0 } {
		puts "<-$a"
		set cmdok 1
	} else {
		# server died?
		if { [eof $chanID] } {
			close $chanID
			puts "End of file on server channel."
			set stopvar 2
			set cmdok 0
		} else {
			puts "neither eof nor empty string..."
		}
	}
}

set comid 0
proc commands {} {
	global stopvar chanID cmdok comid
	# not allow the reading stdin to block the process:
	fconfigure stdin -blocking false
	set prompt 0
	while { $cmdok } {
		if { ! $prompt } {
			puts -nonewline "-> $comid "
			flush stdout
			set prompt 1
		}
		if { [gets stdin a]<0 } { update; continue }
		set prompt 0
		if {[string length $a]==0} {
			set stopvar 1; 
			puts "Stop. Close channel $chanID"
			close $chanID 
			break
		}
		set cmdok false
		puts $chanID "$comid $a"
		flush $chanID
		incr comid
		if {$comid==65536} {set comid 0}
		# wait with next commands until previous command processed or 
		# cmdok is reset to false:
		vwait cmdok
	}
	puts "End of commands"
}

proc bkgr {} {
	after 1000 bkgr
	puts -nonewline \a
	flush stdout
}

# change port and host if supplied:
if {$argc>0} {set port [lindex $argv 0]}
if {$argc>1} {set host [lindex $argv 1]}

puts "Connecting to $host, port $port..."
if {[catch {set chanID [ socket $host $port ]}]} {
	puts "Server not available. Exit"
	exit
} else {
	puts " Connected to $host at port=$port in channel ID $chanID. Input commands:"
	fileevent $chanID readable getreply
}
set stopvar 0
#bkgr
# we have to start commands() on background to enter event loop by the command
# after its start:
after idle commands
vwait stopvar
exit
